<?php
/**
 * Admin Menu Loader
 * 
 * Bu dosya, Auto WebP Converter eklentisinin admin menülerini yükler.
 */

// Doğrudan erişimi engelle
if (!defined('ABSPATH')) {
    exit;
}

// Admin sayfalarını yükle
require_once AWC_PLUGIN_DIR . 'admin/welcome.php';
require_once AWC_PLUGIN_DIR . 'admin/webp-settings.php';
require_once AWC_PLUGIN_DIR . 'admin/dimensions.php';
require_once AWC_PLUGIN_DIR . 'admin/media-management.php';
// Orijinal silme sayfası kaldırıldı
// require_once AWC_PLUGIN_DIR . 'admin/original-delete.php';
require_once AWC_PLUGIN_DIR . 'admin/statistics.php';
require_once AWC_PLUGIN_DIR . 'admin/resize-old-images.php';
require_once AWC_PLUGIN_DIR . 'admin/advanced-webp-conversion.php';

/**
 * Admin menü sınıfı
 */
class AWC_Admin_Menu {
    
    /**
     * Menü başlatma
     */
    public static function init() {
        // Menü öğelerini yeniden düzenle
        add_action('admin_menu', array(__CLASS__, 'rearrange_menu_items'), 100);
        
        // Menü tekrarını önle
        add_action('admin_head', array(__CLASS__, 'remove_duplicate_menu'));
    }
    
    /**
     * Menü öğelerini yeniden düzenler
     */
    public static function rearrange_menu_items() {
        global $submenu;
        
        // Auto WebP Converter menüsü var mı kontrol et
        if (isset($submenu['advanced-image-management'])) {
            // Menü öğelerini yeniden düzenle
            $new_submenu = array();
            
            // Menü sıralaması - Orijinal Silme kaldırıldı
            $menu_order = array(
                'Hoş Geldiniz',
                'WebP Ayarları',
                'Resim Ayarları',
                'Yükleme Ayarları', // Boyut ve Kalite -> Yükleme Ayarları olarak değiştirildi
                'Yeniden Boyutlandırma',
                'Gelişmiş WebP',
                'Medya Yönetimi',
                'İstatistikler'
            );
            
            // Menü öğelerini sırala
            foreach ($menu_order as $menu_title) {
                foreach ($submenu['advanced-image-management'] as $key => $menu_item) {
                    // Boyut ve Kalite -> Yükleme Ayarları olarak değiştirildi
                    if ($menu_item[0] === 'Boyut ve Kalite' && $menu_title === 'Yükleme Ayarları') {
                        $menu_item[0] = 'Yükleme Ayarları';
                        $new_submenu[] = $menu_item;
                        unset($submenu['advanced-image-management'][$key]);
                        break;
                    } elseif ($menu_item[0] === $menu_title) {
                        $new_submenu[] = $menu_item;
                        unset($submenu['advanced-image-management'][$key]);
                        break;
                    }
                }
            }
            
            // Kalan menü öğelerini ekle (Orijinal Silme hariç)
            foreach ($submenu['advanced-image-management'] as $key => $menu_item) {
                if ($menu_item[0] !== 'Orijinal Silme') {
                    $new_submenu[] = $menu_item;
                }
            }
            
            // Menüyü güncelle
            $submenu['advanced-image-management'] = $new_submenu;
        }
    }
    
    /**
     * Menü tekrarını önler
     */
    public static function remove_duplicate_menu() {
        global $menu;
        
        // Menü öğelerini kontrol et
        $auto_webp_count = 0;
        $auto_webp_positions = array();
        
        foreach ($menu as $position => $item) {
            if (isset($item[2]) && $item[2] === 'advanced-image-management') {
                $auto_webp_count++;
                $auto_webp_positions[] = $position;
            }
        }
        
        // Eğer birden fazla Auto WebP menüsü varsa, fazlalıkları kaldır
        if ($auto_webp_count > 1 && count($auto_webp_positions) > 1) {
            // İlk menüyü koru, diğerlerini kaldır
            for ($i = 1; $i < count($auto_webp_positions); $i++) {
                unset($menu[$auto_webp_positions[$i]]);
            }
        }
    }
}

// Menüyü başlat
AWC_Admin_Menu::init();
