<?php
/**
 * Admin Menu: Yükleme Ayarları
 * 
 * Bu dosya, Auto WebP Converter eklentisinin Yükleme Ayarları sayfasını içerir.
 */

// Doğrudan erişimi engelle
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Yükleme Ayarları sayfası sınıfı
 */
class AWC_Dimensions_Page {
    
    /**
     * Sayfa başlatma
     */
    public static function init() {
        add_action('admin_menu', array(__CLASS__, 'add_menu_page'), 60);
        add_action('admin_init', array(__CLASS__, 'register_settings'));
    }
    
    /**
     * Menü sayfasını ekler
     */
    public static function add_menu_page() {
        add_submenu_page(
            'advanced-image-management',
            __('Yükleme Ayarları', 'advanced-image-management'),
            __('Yükleme Ayarları', 'advanced-image-management'),
            'manage_options',
            'advanced-image-management-dimensions',
            array(__CLASS__, 'render_page')
        );
    }
    
    /**
     * Ayarları kaydeder
     */
    public static function register_settings() {
        // Yükleme ayarları
        register_setting('awc_dimensions_settings_group', 'awc_settings', array('Auto_WebP_Converter', 'sanitize_settings'));
        
        // Yükleme ayarları bölümleri
        add_settings_section(
            'awc_general_upload_section',
            __('Genel Yükleme Ayarları', 'advanced-image-management'),
            array(__CLASS__, 'render_general_upload_section'),
            'advanced-image-management-dimensions'
        );
        
        add_settings_section(
            'awc_original_image_section',
            __('Orijinal Resim Ayarları', 'advanced-image-management'),
            array(__CLASS__, 'render_original_image_section'),
            'advanced-image-management-dimensions'
        );
        
        add_settings_section(
            'awc_webp_image_section',
            __('WebP Resim Ayarları', 'advanced-image-management'),
            array(__CLASS__, 'render_webp_image_section'),
            'advanced-image-management-dimensions'
        );
        
        add_settings_section(
            'awc_custom_sizes_section',
            __('Özel Boyut Ayarları', 'advanced-image-management'),
            array(__CLASS__, 'render_custom_sizes_section'),
            'advanced-image-management-dimensions'
        );
        
        // Genel yükleme ayarları alanları
        add_settings_field(
            'only_original_size',
            __('Sadece Orijinal Boyutu Yükle', 'advanced-image-management'),
            array(__CLASS__, 'render_only_original_size_field'),
            'advanced-image-management-dimensions',
            'awc_general_upload_section'
        );
        
        // Orijinal resim ayarları alanları
        add_settings_field(
            'original_image_width',
            __('Genişlik', 'advanced-image-management'),
            array(__CLASS__, 'render_original_image_width_field'),
            'advanced-image-management-dimensions',
            'awc_original_image_section'
        );
        
        add_settings_field(
            'original_image_height',
            __('Yükseklik', 'advanced-image-management'),
            array(__CLASS__, 'render_original_image_height_field'),
            'advanced-image-management-dimensions',
            'awc_original_image_section'
        );
        
        add_settings_field(
            'upload_quality',
            __('Kalite', 'advanced-image-management'),
            array(__CLASS__, 'render_upload_quality_field'),
            'advanced-image-management-dimensions',
            'awc_original_image_section'
        );
        
        // WebP resim ayarları alanları
        add_settings_field(
            'webp_image_width',
            __('Genişlik', 'advanced-image-management'),
            array(__CLASS__, 'render_webp_image_width_field'),
            'advanced-image-management-dimensions',
            'awc_webp_image_section'
        );
        
        add_settings_field(
            'webp_image_height',
            __('Yükseklik', 'advanced-image-management'),
            array(__CLASS__, 'render_webp_image_height_field'),
            'advanced-image-management-dimensions',
            'awc_webp_image_section'
        );
        
        add_settings_field(
            'webp_quality',
            __('Kalite', 'advanced-image-management'),
            array(__CLASS__, 'render_webp_quality_field'),
            'advanced-image-management-dimensions',
            'awc_webp_image_section'
        );
    }
    
    /**
     * Genel Yükleme Ayarları bölümünü render eder
     */
    public static function render_general_upload_section() {
        echo '<p>' . esc_html(__('Bu bölümde, resim yükleme işlemi ile ilgili genel ayarları yapılandırabilirsiniz.', 'advanced-image-management')) . '</p>';
    }
    
    /**
     * Orijinal Resim Ayarları bölümünü render eder
     */
    public static function render_original_image_section() {
        echo '<p>' . esc_html(__('Bu bölümde, orijinal resimlerin boyut ve kalite ayarlarını yapılandırabilirsiniz. Boyut değeri 0 olarak ayarlanırsa, orijinal boyut korunur.', 'advanced-image-management')) . '</p>';
    }
    
    /**
     * WebP Resim Ayarları bölümünü render eder
     */
    public static function render_webp_image_section() {
        echo '<p>' . esc_html(__('Bu bölümde, WebP resimlerinin boyut ve kalite ayarlarını yapılandırabilirsiniz. Boyut değeri 0 olarak ayarlanırsa, orijinal boyut korunur.', 'advanced-image-management')) . '</p>';
    }
    
    /**
     * Özel Boyut Ayarları bölümünü render eder
     */
    public static function render_custom_sizes_section() {
        echo '<p>' . esc_html(__('Bu bölümde, WordPress\'in varsayılan boyutları dışında özel boyutlar tanımlayabilirsiniz. Her özel boyut için genişlik, yükseklik ve kalite değerlerini ayarlayabilirsiniz.', 'advanced-image-management')) . '</p>';
        
        // Özel boyutlar için JavaScript
        ?>
        <div id="awc-custom-sizes-container">
            <div id="awc-custom-sizes-list">
                <?php
                $settings = get_option('awc_settings', array());
                $custom_sizes = isset($settings['custom_sizes']) ? $settings['custom_sizes'] : array();
                
                if (!empty($custom_sizes)) {
                    foreach ($custom_sizes as $index => $size) {
                        ?>
                        <div class="awc-custom-size-item">
                            <h4><?php
							/* translators: %s: Özel boyut belirtir */
							echo sprintf(__('Özel Boyut #%d', 'advanced-image-management'),  esc_html($index) + 1);
							?></h4>
                            <div class="awc-custom-size-fields">
                                <div class="awc-custom-size-field">
                                    <label><?php esc_html_e('İsim', 'advanced-image-management'); ?></label>
                                    <input type="text" name="awc_settings[custom_sizes][<?php echo esc_html($index); ?>][name]" value="<?php echo esc_attr($size['name']); ?>" placeholder="<?php esc_html_e('örn: özel-orta', 'advanced-image-management'); ?>" />
                                </div>
                                <div class="awc-custom-size-field">
                                    <label><?php esc_html_e('Genişlik', 'advanced-image-management'); ?></label>
                                    <input type="number" name="awc_settings[custom_sizes][<?php echo esc_html($index); ?>][width]" value="<?php echo esc_attr($size['width']); ?>" min="0" />
                                </div>
                                <div class="awc-custom-size-field">
                                    <label><?php esc_html_e('Yükseklik', 'advanced-image-management'); ?></label>
                                    <input type="number" name="awc_settings[custom_sizes][<?php echo esc_html($index); ?>][height]" value="<?php echo esc_attr($size['height']); ?>" min="0" />
                                </div>
                                <div class="awc-custom-size-field">
                                    <label><?php esc_html_e('Kalite', 'advanced-image-management'); ?></label>
                                    <input type="number" name="awc_settings[custom_sizes][<?php echo esc_html($index); ?>][quality]" value="<?php echo esc_attr($size['quality']); ?>" min="0" max="100" />
                                </div>
                                <div class="awc-custom-size-field">
                                    <label>&nbsp;</label>
                                    <button type="button" class="button awc-remove-custom-size"><?php esc_html_e('Kaldır', 'advanced-image-management'); ?></button>
                                </div>
                            </div>
                        </div>
                        <?php
                    }
                }
                ?>
            </div>
            <button type="button" class="button" id="awc-add-custom-size"><?php esc_html_e('Yeni Özel Boyut Ekle', 'advanced-image-management'); ?></button>
        </div>
        
        <script>
            jQuery(document).ready(function($) {
                // Yeni özel boyut ekle
                $('#awc-add-custom-size').on('click', function() {
                    var index = $('.awc-custom-size-item').length;
                    var html = '<div class="awc-custom-size-item">';
                    html += '<h4><?php echo __('Özel Boyut #', 'advanced-image-management'); ?>' + (index + 1) + '</h4>';
                    html += '<div class="awc-custom-size-fields">';
                    html += '<div class="awc-custom-size-field">';
                    html += '<label><?php esc_html_e('İsim', 'advanced-image-management'); ?></label>';
                    html += '<input type="text" name="awc_settings[custom_sizes][' + index + '][name]" value="" placeholder="<?php esc_html_e('örn: özel-orta', 'advanced-image-management'); ?>" />';
                    html += '</div>';
                    html += '<div class="awc-custom-size-field">';
                    html += '<label><?php esc_html_e('Genişlik', 'advanced-image-management'); ?></label>';
                    html += '<input type="number" name="awc_settings[custom_sizes][' + index + '][width]" value="0" min="0" />';
                    html += '</div>';
                    html += '<div class="awc-custom-size-field">';
                    html += '<label><?php esc_html_e('Yükseklik', 'advanced-image-management'); ?></label>';
                    html += '<input type="number" name="awc_settings[custom_sizes][' + index + '][height]" value="0" min="0" />';
                    html += '</div>';
                    html += '<div class="awc-custom-size-field">';
                    html += '<label><?php esc_html_e('Kalite', 'advanced-image-management'); ?></label>';
                    html += '<input type="number" name="awc_settings[custom_sizes][' + index + '][quality]" value="90" min="0" max="100" />';
                    html += '</div>';
                    html += '<div class="awc-custom-size-field">';
                    html += '<label>&nbsp;</label>';
                    html += '<button type="button" class="button awc-remove-custom-size"><?php esc_html_e('Kaldır', 'advanced-image-management'); ?></button>';
                    html += '</div>';
                    html += '</div>';
                    html += '</div>';
                    
                    $('#awc-custom-sizes-list').append(html);
                });
                
                // Özel boyutu kaldır
                $(document).on('click', '.awc-remove-custom-size', function() {
                    $(this).closest('.awc-custom-size-item').remove();
                    
                    // Özel boyut indekslerini güncelle
                    $('.awc-custom-size-item').each(function(index) {
                        $(this).find('h4').text('<?php echo __('Özel Boyut #', 'advanced-image-management'); ?>' + (index + 1));
                        
                        $(this).find('input').each(function() {
                            var name = $(this).attr('name');
                            name = name.replace(/\[custom_sizes\]\[\d+\]/, '[custom_sizes][' + index + ']');
                            $(this).attr('name', name);
                        });
                    });
                });
            });
        </script>
        
        <style>
            .awc-custom-size-item {
                margin-bottom: 20px;
                padding: 15px;
                background-color: #f9f9f9;
                border: 1px solid #e0e0e0;
                border-radius: 3px;
            }
            
            .awc-custom-size-item h4 {
                margin-top: 0;
                margin-bottom: 10px;
            }
            
            .awc-custom-size-fields {
                display: flex;
                flex-wrap: wrap;
                gap: 10px;
            }
            
            .awc-custom-size-field {
                flex: 1;
                min-width: 150px;
            }
            
            .awc-custom-size-field label {
                display: block;
                margin-bottom: 5px;
            }
            
            .awc-custom-size-field input {
                width: 100%;
            }
            
            #awc-add-custom-size {
                margin-top: 10px;
            }
        </style>
        <?php
    }
    
    /**
     * Sadece Orijinal Boyutu Yükle alanını render eder
     */
    public static function render_only_original_size_field() {
        $settings = get_option('awc_settings', array());
        $only_original_size = isset($settings['only_original_size']) ? $settings['only_original_size'] : 'no';
        ?>
        <label>
            <input type="checkbox" name="awc_settings[only_original_size]" <?php checked($only_original_size, 'yes'); ?> />
            <?php esc_html_e('Sadece orijinal boyutu yükle, diğer boyutları oluşturma', 'advanced-image-management'); ?>
        </label>
        <p class="description"><?php esc_html_e('Bu seçenek etkinleştirildiğinde, WordPress\'in oluşturduğu thumbnail, medium, large gibi boyutlar oluşturulmaz, sadece orijinal boyut yüklenir.', 'advanced-image-management'); ?></p>
        <?php
    }
    
    /**
     * Orijinal Resim Genişliği alanını render eder
     */
    public static function render_original_image_width_field() {
        $settings = get_option('awc_settings', array());
        $original_image_width = isset($settings['original_image_width']) ? $settings['original_image_width'] : 0;
        ?>
        <input type="number" name="awc_settings[original_image_width]" value="<?php echo esc_attr($original_image_width); ?>" min="0" />
        <p class="description"><?php esc_html_e('Orijinal resmin genişliğini piksel cinsinden ayarlayın. 0 değeri, orijinal boyutu korur.', 'advanced-image-management'); ?></p>
        <?php
    }
    
    /**
     * Orijinal Resim Yüksekliği alanını render eder
     */
    public static function render_original_image_height_field() {
        $settings = get_option('awc_settings', array());
        $original_image_height = isset($settings['original_image_height']) ? $settings['original_image_height'] : 0;
        ?>
        <input type="number" name="awc_settings[original_image_height]" value="<?php echo esc_attr($original_image_height); ?>" min="0" />
        <p class="description"><?php esc_html_e('Orijinal resmin yüksekliğini piksel cinsinden ayarlayın. 0 değeri, orijinal boyutu korur.', 'advanced-image-management'); ?></p>
        <?php
    }
    
    /**
     * Yükleme Kalitesi alanını render eder
     */
    public static function render_upload_quality_field() {
        $settings = get_option('awc_settings', array());
        $upload_quality = isset($settings['upload_quality']) ? $settings['upload_quality'] : 90;
        ?>
        <input type="range" id="upload_quality" name="awc_settings[upload_quality]" min="0" max="100" value="<?php echo esc_attr($upload_quality); ?>" class="awc-range" />
        <span class="awc-range-value"><?php echo esc_html($upload_quality); ?></span>
        <p class="description"><?php esc_html_e('Orijinal resimlerin kalitesini ayarlayın. Düşük değerler daha küçük dosya boyutu sağlar, ancak kaliteyi düşürür.', 'advanced-image-management'); ?></p>
        <script>
            jQuery(document).ready(function($) {
                $('#upload_quality').on('input', function() {
                    $(this).next('.awc-range-value').text($(this).val());
                });
            });
        </script>
        <?php
    }
    
    /**
     * WebP Resim Genişliği alanını render eder
     */
    public static function render_webp_image_width_field() {
        $settings = get_option('awc_settings', array());
        $webp_image_width = isset($settings['webp_image_width']) ? $settings['webp_image_width'] : 0;
        ?>
        <input type="number" name="awc_settings[webp_image_width]" value="<?php echo esc_attr($webp_image_width); ?>" min="0" />
        <p class="description"><?php esc_html_e('WebP resmin genişliğini piksel cinsinden ayarlayın. 0 değeri, orijinal boyutu korur.', 'advanced-image-management'); ?></p>
        <?php
    }
    
    /**
     * WebP Resim Yüksekliği alanını render eder
     */
    public static function render_webp_image_height_field() {
        $settings = get_option('awc_settings', array());
        $webp_image_height = isset($settings['webp_image_height']) ? $settings['webp_image_height'] : 0;
        ?>
        <input type="number" name="awc_settings[webp_image_height]" value="<?php echo esc_attr($webp_image_height); ?>" min="0" />
        <p class="description"><?php esc_html_e('WebP resmin yüksekliğini piksel cinsinden ayarlayın. 0 değeri, orijinal boyutu korur.', 'advanced-image-management'); ?></p>
        <?php
    }
    
    /**
     * WebP Kalitesi alanını render eder
     */
    public static function render_webp_quality_field() {
        $settings = get_option('awc_settings', array());
        $webp_quality = isset($settings['webp_quality']) ? $settings['webp_quality'] : 80;
        ?>
        <input type="range" id="webp_quality" name="awc_settings[webp_quality]" min="0" max="100" value="<?php echo esc_attr($webp_quality); ?>" class="awc-range" />
        <span class="awc-range-value"><?php echo esc_html($webp_quality); ?></span>
        <p class="description"><?php esc_html_e('WebP resimlerinin kalitesini ayarlayın. Düşük değerler daha küçük dosya boyutu sağlar, ancak kaliteyi düşürür.', 'advanced-image-management'); ?></p>
        <script>
            jQuery(document).ready(function($) {
                $('#webp_quality').on('input', function() {
                    $(this).next('.awc-range-value').text($(this).val());
                });
            });
        </script>
        <?php
    }
    
    /**
     * Sayfayı render eder
     */
    public static function render_page() {
        ?>
        <div class="wrap">
            <h1><?php esc_html_e('Yükleme Ayarları', 'advanced-image-management'); ?></h1>
            
            <div class="notice notice-info">
                <p><?php esc_html_e('Bu sayfada, yüklenen resimlerin boyut ve kalite ayarlarını yapılandırabilirsiniz. Ayrıca, özel boyutlar tanımlayabilirsiniz.', 'advanced-image-management'); ?></p>
                <p><?php esc_html_e('Not: Mevcut resimleri yeniden boyutlandırmak için "Yeniden Boyutlandırma" sayfasını kullanın.', 'advanced-image-management'); ?></p>
            </div>
            
            <form method="post" action="options.php">
                <?php settings_fields('awc_dimensions_settings_group'); ?>
                <?php do_settings_sections('advanced-image-management-dimensions'); ?>
                <?php submit_button(__('Ayarları Kaydet', 'advanced-image-management')); ?>
            </form>
            
            <div class="awc-resize-section">
                <h2><?php esc_html_e('Eski Resimleri Yeniden Boyutlandırma', 'advanced-image-management'); ?></h2>
                <p><?php esc_html_e('Mevcut resimleri yeniden boyutlandırmak için Yeniden Boyutlandırma sayfasını kullanın. Bu sayfa, klasör bazlı yeniden boyutlandırma ve detaylı analiz imkanı sunar.', 'advanced-image-management'); ?></p>
                <a href="<?php echo admin_url('admin.php?page=advanced-image-management-resize'); ?>" class="button button-primary"><?php esc_html_e('Yeniden Boyutlandırma Sayfasına Git', 'advanced-image-management'); ?></a>
            </div>
        </div>
        <?php
    }
}

// Sayfayı başlat
AWC_Dimensions_Page::init();
