<?php
/**
 * Admin Menu: Medya Yönetimi
 * 
 * Bu dosya, Auto WebP Converter eklentisinin Medya Yönetimi sayfasını içerir.
 */

// Doğrudan erişimi engelle
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Medya Yönetimi sayfası sınıfı
 */
class AWC_Media_Management_Page {
    
    /**
     * Sayfa başlatma
     */
    public static function init() {
        add_action('admin_menu', array(__CLASS__, 'add_menu_page'), 30);
    }
    
    /**
     * Menü sayfasını ekler
     */
    public static function add_menu_page() {
        add_submenu_page(
            'advanced-image-management',
            __('Medya Yönetimi', 'advanced-image-management'),
            __('Medya Yönetimi', 'advanced-image-management'),
            'manage_options',
            'advanced-image-management-media',
            array(__CLASS__, 'render_page')
        );
    }
    
    /**
     * Sayfayı render eder
     */
    public static function render_page() {
        ?>
        <div class="wrap">
            <h1><?php esc_html_e('Medya Yönetimi', 'advanced-image-management'); ?></h1>
            <div class="awc-media-management">
                <div class="awc-section">
                    <h2><?php esc_html_e('Medya Kütüphanesi Analizi', 'advanced-image-management'); ?></h2>
                    <p><?php esc_html_e('Medya kütüphanesindeki resimleri analiz edin ve WebP dönüşüm durumunu kontrol edin.', 'advanced-image-management'); ?></p>
                    <button type="button" class="button" id="awc-analyze-media"><?php esc_html_e('Analiz Et', 'advanced-image-management'); ?></button>
                    <div id="awc-analyze-results" style="display: none;">
                        <h3><?php esc_html_e('Analiz Sonuçları', 'advanced-image-management'); ?></h3>
                        <table class="widefat">
                            <thead>
                                <tr>
                                    <th><?php esc_html_e('Toplam Resim', 'advanced-image-management'); ?></th>
                                    <th><?php esc_html_e('WebP Dönüştürülen', 'advanced-image-management'); ?></th>
                                    <th><?php esc_html_e('Dönüştürülmeyen', 'advanced-image-management'); ?></th>
                                    <th><?php esc_html_e('Toplam Boyut', 'advanced-image-management'); ?></th>
                                    <th><?php esc_html_e('WebP Boyut', 'advanced-image-management'); ?></th>
                                    <th><?php esc_html_e('Tasarruf', 'advanced-image-management'); ?></th>
                                </tr>
                            </thead>
                            <tbody>
                                <tr>
                                    <td id="awc-total-images">0</td>
                                    <td id="awc-converted-images">0</td>
                                    <td id="awc-not-converted-images">0</td>
                                    <td id="awc-total-size">0 KB</td>
                                    <td id="awc-webp-size">0 KB</td>
                                    <td id="awc-saved-size">0 KB (0%)</td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                    
                    <div id="awc-variations-container" style="display: none; margin-top: 20px;">
                        <h3><?php esc_html_e('Resim Varyasyonları', 'advanced-image-management'); ?></h3>
                        <p><?php esc_html_e('Aşağıdaki varyasyon kategorilerini seçerek silebilirsiniz. Silmek istediğiniz kategorileri işaretleyin ve "Seçili Kategorileri Sil" butonuna tıklayın.', 'advanced-image-management'); ?></p>
                        
                        <div class="awc-variations-actions">
                            <button type="button" class="button button-primary" id="awc-delete-selected-variations"><?php esc_html_e('Seçili Kategorileri Sil', 'advanced-image-management'); ?></button>
                            <button type="button" class="button" id="awc-select-all-variations"><?php esc_html_e('Tümünü Seç', 'advanced-image-management'); ?></button>
                            <button type="button" class="button" id="awc-deselect-all-variations"><?php esc_html_e('Tümünü Kaldır', 'advanced-image-management'); ?></button>
                        </div>
                        
                        <div id="awc-variations-list" class="awc-variations-list"></div>
                        
                        <div id="awc-delete-progress" style="display: none; margin-top: 20px;">
                            <div class="awc-progress-bar">
                                <div class="awc-progress-bar-inner"></div>
                            </div>
                            <div class="awc-progress-text">0%</div>
                        </div>
                    </div>
                </div>
                
                <div class="awc-section">
                    <h2><?php esc_html_e('Dizin Yapısı', 'advanced-image-management'); ?></h2>
                    <p><?php esc_html_e('Upload dizinindeki klasör yapısını görüntüleyin ve belirli klasörlerdeki resimleri analiz edin.', 'advanced-image-management'); ?></p>
                    <button type="button" class="button" id="awc-get-directory-structure"><?php esc_html_e('Dizin Yapısını Göster', 'advanced-image-management'); ?></button>
                    <div id="awc-directory-structure" style="display: none;">
                        <h3><?php esc_html_e('Dizin Yapısı', 'advanced-image-management'); ?></h3>
                        <div id="awc-directory-tree"></div>
                    </div>
                </div>
            </div>
        </div>
        <script>
            jQuery(document).ready(function($) {
                // Medya kütüphanesini analiz et
                $('#awc-analyze-media').on('click', function() {
                    var button = $(this);
                    button.prop('disabled', true);
                    
                    var data = {
                        action: 'awc_get_statistics',
                        nonce: '<?php echo wp_create_nonce('awc_get_statistics'); ?>'
                    };
                    
                    $.post(ajaxurl, data, function(response) {
                        if (response.success) {
                            $('#awc-total-images').text(response.data.total_images);
                            $('#awc-converted-images').text(response.data.converted_images);
                            $('#awc-not-converted-images').text(response.data.not_converted_images);
                            $('#awc-total-size').text(response.data.total_size);
                            $('#awc-webp-size').text(response.data.webp_size);
                            $('#awc-saved-size').text(response.data.saved_size);
                            
                            $('#awc-analyze-results').show();
                            
                            // Varyasyonları getir
                            getImageVariations();
                        } else {
                            alert('<?php esc_html_e('Medya kütüphanesi analiz edilirken bir hata oluştu!', 'advanced-image-management'); ?>');
                        }
                        
                        button.prop('disabled', false);
                    });
                });
                
                // Resim varyasyonlarını getir
                function getImageVariations() {
                    var data = {
                        action: 'awc_get_image_variations',
                        nonce: '<?php echo wp_create_nonce('awc_get_image_variations'); ?>'
                    };
                    
                    $.post(ajaxurl, data, function(response) {
                        if (response.success) {
                            renderVariations(response.data.variations);
                            $('#awc-variations-container').show();
                        } else {
                            alert('<?php esc_html_e('Resim varyasyonları alınırken bir hata oluştu!', 'advanced-image-management'); ?>');
                        }
                    });
                }
                
                // Varyasyonları render et
                function renderVariations(variations) {
                    var html = '';
                    
                    $.each(variations, function(key, variation) {
                        html += '<div class="awc-variation-category">';
                        html += '<div class="awc-variation-header">';
                        html += '<input type="checkbox" class="awc-variation-category-checkbox" id="awc-variation-category-' + key + '" data-category="' + key + '" />';
                        html += '<label for="awc-variation-category-' + key + '">';
                        html += '<strong>' + variation.name + '</strong> ';
                        html += '(' + variation.count + ' dosya, ' + formatBytes(variation.size) + ')';
                        html += '</label>';
                        html += '</div>';
                        html += '</div>';
                    });
                    
                    $('#awc-variations-list').html(html);
                }
                
                // Boyut formatla
                function formatBytes(bytes, decimals = 2) {
                    if (bytes === 0) return '0 Bytes';
                    
                    const k = 1024;
                    const dm = decimals < 0 ? 0 : decimals;
                    const sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
                    
                    const i = Math.floor(Math.log(bytes) / Math.log(k));
                    
                    return parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i];
                }
                
                // Tümünü seç
                $('#awc-select-all-variations').on('click', function() {
                    $('.awc-variation-category-checkbox').prop('checked', true);
                });
                
                // Tümünü kaldır
                $('#awc-deselect-all-variations').on('click', function() {
                    $('.awc-variation-category-checkbox').prop('checked', false);
                });
                
                // Seçili varyasyonları sil
                $('#awc-delete-selected-variations').on('click', function() {
                    var selectedCategories = [];
                    
                    $('.awc-variation-category-checkbox:checked').each(function() {
                        selectedCategories.push($(this).data('category'));
                    });
                    
                    if (selectedCategories.length === 0) {
                        alert('<?php esc_html_e('Lütfen silmek istediğiniz varyasyon kategorilerini seçin!', 'advanced-image-management'); ?>');
                        return;
                    }
                    
                    if (confirm('<?php esc_html_e('Seçili varyasyon kategorilerini silmek istediğinize emin misiniz? Bu işlem geri alınamaz!', 'advanced-image-management'); ?>')) {
                        var button = $(this);
                        button.prop('disabled', true);
                        
                        $('#awc-delete-progress').show();
                        $('.awc-progress-bar-inner').css('width', '0%');
                        $('.awc-progress-text').text('0%');
                        
                        var data = {
                            action: 'awc_delete_selected_variation_categories',
                            categories: selectedCategories,
                            nonce: '<?php echo wp_create_nonce('awc_delete_selected_variation_categories'); ?>'
                        };
                        
                        $.post(ajaxurl, data, function(response) {
                            if (response.success) {
                                $('.awc-progress-bar-inner').css('width', '100%');
                                $('.awc-progress-text').text('100%');
                                
                                alert(response.data.message);
                                
                                // Yeniden analiz et
                                $('#awc-analyze-media').trigger('click');
                            } else {
                                alert('<?php esc_html_e('Varyasyonlar silinirken bir hata oluştu!', 'advanced-image-management'); ?>');
                                $('.awc-progress-bar-inner').css('width', '0%');
                                $('.awc-progress-text').text('0%');
                            }
                            
                            button.prop('disabled', false);
                        });
                    }
                });
                
                // Dizin yapısını göster
                $('#awc-get-directory-structure').on('click', function() {
                    var button = $(this);
                    button.prop('disabled', true);
                    
                    var data = {
                        action: 'awc_get_directory_structure',
                        nonce: '<?php echo wp_create_nonce('awc_get_directory_structure'); ?>'
                    };
                    
                    $.post(ajaxurl, data, function(response) {
                        if (response.success) {
                            var html = '<ul class="awc-directory-list">';
                            
                            $.each(response.data.directories, function(index, directory) {
                                html += '<li>';
                                html += '<span class="awc-directory-name">' + directory.name + '</span>';
                                html += '<button type="button" class="button awc-analyze-directory" data-directory="' + directory.path + '"><?php esc_html_e('Analiz Et', 'advanced-image-management'); ?></button>';
                                
                                if (directory.subdirectories.length > 0) {
                                    html += '<ul class="awc-subdirectory-list">';
                                    
                                    $.each(directory.subdirectories, function(subIndex, subdirectory) {
                                        html += '<li>';
                                        html += '<span class="awc-directory-name">' + subdirectory.name + '</span>';
                                        html += '<button type="button" class="button awc-analyze-directory" data-directory="' + subdirectory.path + '"><?php esc_html_e('Analiz Et', 'advanced-image-management'); ?></button>';
                                        html += '</li>';
                                    });
                                    
                                    html += '</ul>';
                                }
                                
                                html += '</li>';
                            });
                            
                            html += '</ul>';
                            
                            $('#awc-directory-tree').html(html);
                            $('#awc-directory-structure').show();
                        } else {
                            alert('<?php esc_html_e('Dizin yapısı alınırken bir hata oluştu!', 'advanced-image-management'); ?>');
                        }
                        
                        button.prop('disabled', false);
                    });
                });
                
                // Dizini analiz et
                $(document).on('click', '.awc-analyze-directory', function() {
                    var button = $(this);
                    var directory = button.data('directory');
                    
                    button.prop('disabled', true);
                    
                    var data = {
                        action: 'awc_analyze_directory',
                        directory: directory,
                        nonce: '<?php echo wp_create_nonce('awc_analyze_directory'); ?>'
                    };
                    
                    $.post(ajaxurl, data, function(response) {
                        if (response.success) {
                            var resultHtml = '<div class="awc-directory-analysis">';
                            resultHtml += '<h4><?php esc_html_e('Analiz Sonuçları', 'advanced-image-management'); ?>: ' + directory + '</h4>';
                            resultHtml += '<table class="widefat">';
                            resultHtml += '<thead><tr><th><?php esc_html_e('Toplam Resim', 'advanced-image-management'); ?></th><th><?php esc_html_e('WebP Dönüştürülen', 'advanced-image-management'); ?></th><th><?php esc_html_e('Dönüştürülmeyen', 'advanced-image-management'); ?></th><th><?php esc_html_e('Toplam Boyut', 'advanced-image-management'); ?></th><th><?php esc_html_e('WebP Boyut', 'advanced-image-management'); ?></th><th><?php esc_html_e('Tasarruf', 'advanced-image-management'); ?></th></tr></thead>';
                            resultHtml += '<tbody><tr><td>' + response.data.total_images + '</td><td>' + response.data.converted_images + '</td><td>' + response.data.not_converted_images + '</td><td>' + response.data.total_size + '</td><td>' + response.data.webp_size + '</td><td>' + response.data.saved_size + '</td></tr></tbody>';
                            resultHtml += '</table>';
                            resultHtml += '</div>';
                            
                            // Sonuçları göster
                            if (button.next('.awc-directory-analysis').length) {
                                button.next('.awc-directory-analysis').remove();
                            }
                            
                            button.after(resultHtml);
                        } else {
                            alert('<?php esc_html_e('Dizin analiz edilirken bir hata oluştu!', 'advanced-image-management'); ?>');
                        }
                        
                        button.prop('disabled', false);
                    });
                });
            });
        </script>
        
        <style>
            .awc-section {
                margin-bottom: 30px;
                padding: 20px;
                background-color: #fff;
                border: 1px solid #ccc;
                border-radius: 3px;
            }
            
            .awc-directory-list {
                margin-left: 0;
                list-style-type: none;
            }
            
            .awc-subdirectory-list {
                margin-left: 20px;
                list-style-type: none;
            }
            
            .awc-directory-name {
                display: inline-block;
                margin-right: 10px;
                font-weight: bold;
            }
            
            .awc-directory-analysis {
                margin-top: 10px;
                margin-left: 20px;
                margin-bottom: 20px;
            }
            
            .awc-variations-list {
                margin-top: 20px;
            }
            
            .awc-variation-category {
                margin-bottom: 10px;
                padding: 10px;
                background-color: #f9f9f9;
                border: 1px solid #e0e0e0;
                border-radius: 3px;
            }
            
            .awc-variation-header {
                display: flex;
                align-items: center;
            }
            
            .awc-variation-header input[type="checkbox"] {
                margin-right: 10px;
            }
            
            .awc-variations-actions {
                margin-bottom: 15px;
            }
            
            .awc-progress-bar {
                width: 100%;
                height: 20px;
                background-color: #f0f0f0;
                border-radius: 3px;
                margin-bottom: 5px;
            }
            
            .awc-progress-bar-inner {
                width: 0;
                height: 100%;
                background-color: #0073aa;
                border-radius: 3px;
                transition: width 0.3s;
            }
            
            .awc-progress-text {
                text-align: center;
                font-weight: bold;
            }
        </style>
        <?php
    }
}

// Sayfayı başlat
AWC_Media_Management_Page::init();
