<?php
/**
 * Admin Menu: İstatistikler
 * 
 * Bu dosya, Auto WebP Converter eklentisinin İstatistikler sayfasını içerir.
 */

// Doğrudan erişimi engelle
if (!defined('ABSPATH')) {
    exit;
}

/**
 * İstatistikler sayfası sınıfı
 */
class AWC_Statistics_Page {
    
    /**
     * Sayfa başlatma
     */
    public static function init() {
        add_action('admin_menu', array(__CLASS__, 'add_menu_page'), 50);
    }
    
    /**
     * Menü sayfasını ekler
     */
    public static function add_menu_page() {
        add_submenu_page(
            'advanced-image-management',
            __('İstatistikler', 'advanced-image-management'),
            __('İstatistikler', 'advanced-image-management'),
            'manage_options',
            'advanced-image-management-stats',
            array(__CLASS__, 'render_page')
        );
    }
    
    /**
     * Sayfayı render eder
     */
    public static function render_page() {
        $settings = get_option('awc_settings', array());
        $statistics = isset($settings['statistics']) ? $settings['statistics'] : array(
            'original_size' => 0,
            'converted_size' => 0,
            'saved_size' => 0,
            'converted_count' => 0,
            'deleted_count' => 0,
            'last_update' => 0
        );
        
        $original_size = size_format($statistics['original_size']);
        $converted_size = size_format($statistics['converted_size']);
        $saved_size = size_format($statistics['saved_size']);
        $saved_percentage = $statistics['original_size'] > 0 ? round(($statistics['saved_size'] / $statistics['original_size']) * 100, 2) : 0;
        $last_update = $statistics['last_update'] > 0 ? date_i18n(get_option('date_format') . ' ' . get_option('time_format'), $statistics['last_update']) : __('Hiç', 'advanced-image-management');
        ?>
        <div class="wrap">
            <h1><?php esc_html_e('İstatistikler', 'advanced-image-management'); ?></h1>
            <div class="awc-statistics">
                <div class="awc-section">
                    <h2><?php esc_html_e('Genel İstatistikler', 'advanced-image-management'); ?></h2>
                    <table class="widefat">
                        <tbody>
                            <tr>
                                <th><?php esc_html_e('Dönüştürülen Resim Sayısı', 'advanced-image-management'); ?></th>
                                <td><?php echo esc_html($statistics['converted_count']); ?></td>
                            </tr>
                            <tr>
                                <th><?php esc_html_e('Silinen Resim Sayısı', 'advanced-image-management'); ?></th>
                                <td><?php echo esc_html($statistics['deleted_count']); ?></td>
                            </tr>
                            <tr>
                                <th><?php esc_html_e('Orijinal Boyut', 'advanced-image-management'); ?></th>
                                <td><?php echo esc_html($original_size); ?></td>
                            </tr>
                            <tr>
                                <th><?php esc_html_e('Dönüştürülen Boyut', 'advanced-image-management'); ?></th>
                                <td><?php echo esc_html($converted_size); ?></td>
                            </tr>
                            <tr>
                                <th><?php esc_html_e('Tasarruf Edilen Boyut', 'advanced-image-management'); ?></th>
                                <td><?php echo esc_html($saved_size); ?> (<?php echo esc_html($saved_percentage); ?>%)</td>
                            </tr>
                            <tr>
                                <th><?php esc_html_e('Son Güncelleme', 'advanced-image-management'); ?></th>
                                <td><?php echo esc_html($last_update); ?></td>
                            </tr>
                        </tbody>
                    </table>
                    <button type="button" class="button" id="awc-refresh-statistics"><?php esc_html_e('İstatistikleri Güncelle', 'advanced-image-management'); ?></button>
                </div>
                
                <div class="awc-section">
                    <h2><?php esc_html_e('Grafik İstatistikler', 'advanced-image-management'); ?></h2>
                    <div class="awc-chart-container">
                        <canvas id="awc-size-chart"></canvas>
                    </div>
                </div>
            </div>
        </div>
		
		
        <script src="<?php echo AWC_PLUGIN_URL . 'assets/js/chart.js'; ?>"></script>
        <script>
            jQuery(document).ready(function($) {
                // Boyut grafiği
                var sizeCtx = document.getElementById('awc-size-chart').getContext('2d');
                var sizeChart = new Chart(sizeCtx, {
                    type: 'bar',
                    data: {
                        labels: ['<?php esc_html_e('Orijinal Boyut', 'advanced-image-management'); ?>', '<?php esc_html_e('Dönüştürülen Boyut', 'advanced-image-management'); ?>', '<?php esc_html_e('Tasarruf Edilen Boyut', 'advanced-image-management'); ?>'],
                        datasets: [{
                            label: '<?php esc_html_e('Boyut (MB)', 'advanced-image-management'); ?>',
                            data: [
                                <?php echo $statistics['original_size'] / (1024 * 1024); ?>,
                                <?php echo $statistics['converted_size'] / (1024 * 1024); ?>,
                                <?php echo $statistics['saved_size'] / (1024 * 1024); ?>
                            ],
                            backgroundColor: [
                                'rgba(255, 99, 132, 0.2)',
                                'rgba(54, 162, 235, 0.2)',
                                'rgba(75, 192, 192, 0.2)'
                            ],
                            borderColor: [
                                'rgba(255, 99, 132, 1)',
                                'rgba(54, 162, 235, 1)',
                                'rgba(75, 192, 192, 1)'
                            ],
                            borderWidth: 1
                        }]
                    },
                    options: {
                        scales: {
                            y: {
                                beginAtZero: true
                            }
                        }
                    }
                });
                
                $('#awc-refresh-statistics').on('click', function() {
                    var button = $(this);
                    button.prop('disabled', true);
                    
                    var data = {
                        action: 'awc_get_statistics',
                        nonce: '<?php echo wp_create_nonce('awc_get_statistics'); ?>'
                    };
                    
                    $.post(ajaxurl, data, function(response) {
                        if (response.success) {
                            location.reload();
                        } else {
                            alert('<?php esc_html_e('İstatistikler güncellenirken bir hata oluştu!', 'advanced-image-management'); ?>');
                            button.prop('disabled', false);
                        }
                    });
                });
            });
        </script>
        <style>
            .awc-section {
                margin-bottom: 30px;
                padding: 20px;
                background-color: #fff;
                border: 1px solid #ccc;
                border-radius: 3px;
            }
            
            .awc-chart-container {
                width: 100%;
                height: 400px;
            }
        </style>
        <?php
    }
}

// Sayfayı başlat
AWC_Statistics_Page::init();
