<?php
/**
 * Admin Menu: WebP Ayarları
 * 
 * Bu dosya, Auto WebP Converter eklentisinin WebP Ayarları sayfasını içerir.
 */

// Doğrudan erişimi engelle
if (!defined('ABSPATH')) {
    exit;
}

/**
 * WebP Ayarları sayfası sınıfı
 */
class AWC_WebP_Settings_Page {
    
    /**
     * Sayfa başlatma
     */
    public static function init() {
        add_action('admin_menu', array(__CLASS__, 'add_menu_page'), 20);
        add_action('admin_init', array(__CLASS__, 'register_settings'));
    }
    
    /**
     * Menü sayfasını ekler
     */
    public static function add_menu_page() {
        add_submenu_page(
            'advanced-image-management',
            __('WebP Ayarları', 'advanced-image-management'),
            __('WebP Ayarları', 'advanced-image-management'),
            'manage_options',
            'advanced-image-management-webp',
            array(__CLASS__, 'render_page')
        );
    }
    
    /**
     * Ayarları kaydeder
     */
    public static function register_settings() {
        // WebP ayarları
        register_setting('awc_webp_settings_group', 'awc_settings', array('Auto_WebP_Converter', 'sanitize_settings'));
        
        // WebP ayarları bölümleri
        add_settings_section(
            'awc_webp_conversion_section',
            __('WebP Dönüşüm Ayarları', 'advanced-image-management'),
            array(__CLASS__, 'render_webp_conversion_section'),
            'advanced-image-management-webp'
        );
        
        add_settings_section(
            'awc_webp_display_section',
            __('WebP Gösterim Ayarları', 'advanced-image-management'),
            array(__CLASS__, 'render_webp_display_section'),
            'advanced-image-management-webp'
        );
        
        add_settings_section(
            'awc_hosting_section',
            __('Hosting Uyumluluğu', 'advanced-image-management'),
            array(__CLASS__, 'render_hosting_section'),
            'advanced-image-management-webp'
        );
        
        // WebP ayarları alanları
        add_settings_field(
            'convert_new_uploads',
            __('Yeni Yüklemeleri Dönüştür', 'advanced-image-management'),
            array(__CLASS__, 'render_convert_new_uploads_field'),
            'advanced-image-management-webp',
            'awc_webp_conversion_section'
        );
        
        add_settings_field(
            'keep_original',
            __('Orijinal Resimleri Sakla', 'advanced-image-management'),
            array(__CLASS__, 'render_keep_original_field'),
            'advanced-image-management-webp',
            'awc_webp_conversion_section'
        );
        
        add_settings_field(
            'image_formats',
            __('Dönüştürülecek Formatlar', 'advanced-image-management'),
            array(__CLASS__, 'render_image_formats_field'),
            'advanced-image-management-webp',
            'awc_webp_conversion_section'
        );
        
        add_settings_field(
            'webp_priority',
            __('WebP Önceliği', 'advanced-image-management'),
            array(__CLASS__, 'render_webp_priority_field'),
            'advanced-image-management-webp',
            'awc_webp_display_section'
        );
        
        add_settings_field(
            'hosting_compatible',
            __('Hosting Uyumluluğu', 'advanced-image-management'),
            array(__CLASS__, 'render_hosting_compatible_field'),
            'advanced-image-management-webp',
            'awc_hosting_section'
        );
    }
    
    /**
     * WebP Dönüşüm bölümünü render eder
     */
    public static function render_webp_conversion_section() {
        echo '<p>' . __('Bu bölümde, resimlerin WebP formatına dönüştürülme ayarlarını yapılandırabilirsiniz.', 'advanced-image-management') . '</p>';
        echo '<p>' . __('Not: Mevcut resimleri WebP formatına dönüştürmek için "Gelişmiş WebP" sayfasını kullanın.', 'advanced-image-management') . '</p>';
    }
    
    /**
     * WebP Gösterim bölümünü render eder
     */
    public static function render_webp_display_section() {
        echo '<p>' . __('Bu bölümde, WebP resimlerinin gösterim ayarlarını yapılandırabilirsiniz.', 'advanced-image-management') . '</p>';
    }
    
    /**
     * Hosting Uyumluluğu bölümünü render eder
     */
    public static function render_hosting_section() {
        echo '<p>' . __('Bu bölümde, hosting sunucunuzun WebP uyumluluğunu kontrol edebilirsiniz.', 'advanced-image-management') . '</p>';
    }
    
    /**
     * Yeni Yüklemeleri Dönüştür alanını render eder
     */
    public static function render_convert_new_uploads_field() {
        $settings = get_option('awc_settings', array());
        $convert_new_uploads = isset($settings['convert_new_uploads']) ? $settings['convert_new_uploads'] : 'yes';
        ?>
        <label>
            <input type="checkbox" name="awc_settings[convert_new_uploads]" <?php checked($convert_new_uploads, 'yes'); ?> />
            <?php esc_html_e('Yeni yüklenen resimleri otomatik olarak WebP formatına dönüştür', 'advanced-image-management'); ?>
        </label>
        <p class="description"><?php esc_html_e('Bu seçenek etkinleştirildiğinde, yeni yüklenen resimler otomatik olarak WebP formatına dönüştürülür.', 'advanced-image-management'); ?></p>
        <?php
    }
    
    /**
     * Orijinal Resimleri Sakla alanını render eder
     */
    public static function render_keep_original_field() {
        $settings = get_option('awc_settings', array());
        $keep_original = isset($settings['keep_original']) ? $settings['keep_original'] : 'yes';
        ?>
        <label>
            <input type="checkbox" name="awc_settings[keep_original]" <?php checked($keep_original, 'yes'); ?> />
            <?php esc_html_e('Orijinal resimleri sakla', 'advanced-image-management'); ?>
        </label>
        <p class="description"><?php esc_html_e('Bu seçenek etkinleştirildiğinde, orijinal resimler WebP dönüşümünden sonra saklanır. Devre dışı bırakıldığında, orijinal resimler silinir ve sadece WebP versiyonları kalır.', 'advanced-image-management'); ?></p>
        <?php
    }
    
    /**
     * Dönüştürülecek Formatlar alanını render eder
     */
    public static function render_image_formats_field() {
        $settings = get_option('awc_settings', array());
        $image_formats = isset($settings['image_formats']) ? $settings['image_formats'] : array('jpg', 'jpeg', 'png');
        ?>
        <div>
            <label>
                <input type="checkbox" name="awc_settings[image_formats][]" value="jpg" <?php checked(in_array('jpg', $image_formats), true); ?> />
                <?php esc_html_e('JPG', 'advanced-image-management'); ?>
            </label>
        </div>
        <div>
            <label>
                <input type="checkbox" name="awc_settings[image_formats][]" value="jpeg" <?php checked(in_array('jpeg', $image_formats), true); ?> />
                <?php esc_html_e('JPEG', 'advanced-image-management'); ?>
            </label>
        </div>
        <div>
            <label>
                <input type="checkbox" name="awc_settings[image_formats][]" value="png" <?php checked(in_array('png', $image_formats), true); ?> />
                <?php esc_html_e('PNG', 'advanced-image-management'); ?>
            </label>
        </div>
        <div>
            <label>
                <input type="checkbox" name="awc_settings[image_formats][]" value="gif" <?php checked(in_array('gif', $image_formats), true); ?> />
                <?php esc_html_e('GIF', 'advanced-image-management'); ?>
            </label>
        </div>
        <p class="description"><?php esc_html_e('WebP formatına dönüştürülecek resim formatlarını seçin.', 'advanced-image-management'); ?></p>
        <?php
    }
    
    /**
     * WebP Önceliği alanını render eder
     */
    public static function render_webp_priority_field() {
        $settings = get_option('awc_settings', array());
        $webp_priority = isset($settings['webp_priority']) ? $settings['webp_priority'] : 'yes';
        ?>
        <label>
            <input type="checkbox" name="awc_settings[webp_priority]" <?php checked($webp_priority, 'yes'); ?> />
            <?php esc_html_e('WebP formatını öncelikli olarak göster', 'advanced-image-management'); ?>
        </label>
        <p class="description"><?php esc_html_e('Bu seçenek etkinleştirildiğinde, WebP formatı destekleyen tarayıcılarda WebP resimler öncelikli olarak gösterilir.', 'advanced-image-management'); ?></p>
        <?php
    }
    
    /**
     * Hosting Uyumluluğu alanını render eder
     */
    public static function render_hosting_compatible_field() {
        $settings = get_option('awc_settings', array());
        $hosting_compatible = isset($settings['hosting_compatible']) ? $settings['hosting_compatible'] : 'unknown';
        ?>
        <div>
            <div id="awc-hosting-status" class="awc-hosting-status awc-hosting-status-<?php echo esc_attr($hosting_compatible); ?>">
                <?php if ($hosting_compatible === 'yes') : ?>
                    <span class="dashicons dashicons-yes"></span> <?php esc_html_e('Hosting sunucunuz WebP formatını destekliyor.', 'advanced-image-management'); ?>
                <?php elseif ($hosting_compatible === 'no') : ?>
                    <span class="dashicons dashicons-no"></span> <?php esc_html_e('Hosting sunucunuz WebP formatını desteklemiyor.', 'advanced-image-management'); ?>
                <?php else : ?>
                    <span class="dashicons dashicons-warning"></span> <?php esc_html_e('Hosting sunucunuzun WebP uyumluluğu henüz kontrol edilmedi.', 'advanced-image-management'); ?>
                <?php endif; ?>
            </div>
            <input type="hidden" name="awc_settings[hosting_compatible]" id="awc-hosting-compatible" value="<?php echo esc_attr($hosting_compatible); ?>" />
            <button type="button" class="button" id="awc-check-hosting"><?php esc_html_e('Uyumluluğu Kontrol Et', 'advanced-image-management'); ?></button>
        </div>
        <script>
            jQuery(document).ready(function($) {
                $('#awc-check-hosting').on('click', function() {
                    var button = $(this);
                    button.prop('disabled', true);
                    
                    var data = {
                        action: 'awc_check_hosting',
                        nonce: '<?php echo wp_create_nonce('awc_check_hosting'); ?>'
                    };
                    
                    $.post(ajaxurl, data, function(response) {
                        if (response.success) {
                            $('#awc-hosting-status').removeClass('awc-hosting-status-unknown awc-hosting-status-yes awc-hosting-status-no');
                            
                            if (response.data.compatible) {
                                $('#awc-hosting-status').addClass('awc-hosting-status-yes');
                                $('#awc-hosting-status').html('<span class="dashicons dashicons-yes"></span> <?php esc_html_e('Hosting sunucunuz WebP formatını destekliyor.', 'advanced-image-management'); ?>');
                                $('#awc-hosting-compatible').val('yes');
                            } else {
                                $('#awc-hosting-status').addClass('awc-hosting-status-no');
                                $('#awc-hosting-status').html('<span class="dashicons dashicons-no"></span> <?php esc_html_e('Hosting sunucunuz WebP formatını desteklemiyor.', 'advanced-image-management'); ?>');
                                $('#awc-hosting-compatible').val('no');
                            }
                        } else {
                            alert('<?php esc_html_e('Hosting uyumluluğu kontrol edilirken bir hata oluştu!', 'advanced-image-management'); ?>');
                        }
                        
                        button.prop('disabled', false);
                    });
                });
            });
        </script>
        <style>
            .awc-hosting-status {
                padding: 10px;
                margin-bottom: 10px;
                border-radius: 3px;
            }
            
            .awc-hosting-status-yes {
                background-color: #f0fff0;
                border: 1px solid #0f0;
                color: #0a0;
            }
            
            .awc-hosting-status-no {
                background-color: #fff0f0;
                border: 1px solid #f00;
                color: #a00;
            }
            
            .awc-hosting-status-unknown {
                background-color: #ffffd0;
                border: 1px solid #ff0;
                color: #a50;
            }
        </style>
        <?php
    }
    
    /**
     * Sayfayı render eder
     */
    public static function render_page() {
        ?>
        <div class="wrap">
            <h1><?php esc_html_e('WebP Ayarları', 'advanced-image-management'); ?></h1>
            
            <div class="notice notice-info">
                <p><?php esc_html_e('Not: Mevcut resimleri WebP formatına dönüştürmek için "Gelişmiş WebP" sayfasını kullanın. Kalite ve boyut ayarları için "Yükleme Ayarları" sayfasını kullanın.', 'advanced-image-management'); ?></p>
            </div>
            
            <form method="post" action="options.php">
                <?php settings_fields('awc_webp_settings_group'); ?>
                <?php do_settings_sections('advanced-image-management-webp'); ?>
                <?php submit_button(); ?>
            </form>
            
            <div class="awc-advanced-webp-section">
                <h2><?php esc_html_e('Gelişmiş WebP Dönüştürme', 'advanced-image-management'); ?></h2>
                <p><?php esc_html_e('Mevcut resimleri WebP formatına dönüştürmek için Gelişmiş WebP sayfasını kullanın. Bu sayfa, klasör bazlı dönüştürme ve detaylı analiz imkanı sunar.', 'advanced-image-management'); ?></p>
                <a href="<?php echo admin_url('admin.php?page=advanced-image-management-advanced'); ?>" class="button button-primary"><?php esc_html_e('Gelişmiş WebP Sayfasına Git', 'advanced-image-management'); ?></a>
            </div>
        </div>
        <?php
    }
}

// Sayfayı başlat
AWC_WebP_Settings_Page::init();
